pub struct UserState {
pub id: Id,
card_id: Option<CardPseud>,
pub registration_date: Option<NumericDate>,
pub polymorphic_pseudonym: Triple,
pub banned: bool,
pub allow_login_by: HashSet<Id>,
pub could_be_banned_by: HashSet<Id>,
pub stored_objects: HashMap<Handle, UserObjectDetails>,
}Expand description
Details pubhubs central stores about a user’s account
Fields
id: IdRandomly generated identifier for this account, used for creating access tokens and such
card_id: Option<CardPseud>Used as registration pseudonym on pubhubs cards issued for to this user.
Might not be set for users that registered under v3.0.0, but will be upon entering pubhubs.
If not set, it’s derived from UserState::id, which is done by UserState::card_id().
registration_date: Option<NumericDate>Registration date for this user
Might not be set for users that registered under v3.0.0.
polymorphic_pseudonym: TripleRandomly generated and by Constellation::master_enc_key elgamal encrypted
identifier used to generate hub pseudonyms for this user.
banned: boolWhether this account is banned
allow_login_by: HashSet<Id>Attributes that may be used to log in as this user,
provided that AttrState::may_identify_user also points to this account.
The user may remove an attribute from this list.
could_be_banned_by: HashSet<Id>Attributes that when banned will ban this user
The user can only add attributes to this list, but not remove them.
This list is used to keep track of whether there is at least one attribute that would ban this user. If there are none, the user must add a bannable attribute before they can login in.
stored_objects: HashMap<Handle, UserObjectDetails>Details about the objects stored by this user at pubhubs central
Implementations
Sourceimpl UserState
impl UserState
Sourcepub fn card_id(&self) -> CardPseud
pub fn card_id(&self) -> CardPseud
Returns UserState::card_id when available, and otherwise an Id derived from UserState::id.
Sourcepub(crate) fn update_quota(&self, quota: Quota) -> Result<Quota, QuotumName>
pub(crate) fn update_quota(&self, quota: Quota) -> Result<Quota, QuotumName>
Subtract quota usage from the given Quota, returning an error when a QuotumName was
reached.
Sourcepub(crate) fn into_user_version(self: UserState, app: &App) -> ApiUserState
pub(crate) fn into_user_version(self: UserState, app: &App) -> ApiUserState
Turns this UserState into a ApiUserState.